/*--------------------------------------------------------------------------*/
/*--------------------------- File DCRwriter.h -----------------------------*/
/*--------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/*----------------------------- DEFINITIONS --------------------------------*/
/*--------------------------------------------------------------------------*/

#ifndef DCR_GEN_H
#define DCR_GEN_H

/*--------------------------------------------------------------------------*/
/*------------------------------ INCLUDES ----------------------------------*/
/*--------------------------------------------------------------------------*/

#include "DCR.h"

#include "topology.h"
#include "edge.h"
#include "pair.h"
#include "parser.h"
#include "traffic-matrix.h"

#include <exception>
#include <iostream>
#include <set>
#include <sstream>

/*--------------------------------------------------------------------------*/
/*--------------------------- CLASS DCRwriter ------------------------------*/
/*--------------------------------------------------------------------------*/

class DCRwriter
{
	
/*--------------------------------------------------------------------------*/
/*----------------------- PUBLIC PART OF THE CLASS -------------------------*/
/*--------------------------------------------------------------------------*/	

 public:

/*--------------------------------------------------------------------------*/
/*---------------------------- CONSTRUCTOR ---------------------------------*/
/*--------------------------------------------------------------------------*/

  DCRwriter( char * topofile , char * traffile , char * name , char type);	

/*--------------------------------------------------------------------------*/
/*---------------------------- GET METHODS ---------------------------------*/
/*--------------------------------------------------------------------------*/

  int getNumNodes();

  int getNumLinks();

  int getNumFlows();

/*--------------------------------------------------------------------------*/
/*------------------------------ GENERATION --------------------------------*/
/*--------------------------------------------------------------------------*/

  void Generate();

/*--------------------------------------------------------------------------*/
/*------------------------------ DESTRUCTOR --------------------------------*/
/*--------------------------------------------------------------------------*/

  ~DCRwriter();

/*--------------------------------------------------------------------------*/
/*--------------------- PRIVATE PART OF THE CLASS --------------------------*/
/*--------------------------------------------------------------------------*/	
	
 private:

  void FNSSgetFlows();

  void FNSSgetLinks();

  void write2MulgenFormat();

  void write2MnetgenFormat();

/*--------------------------------------------------------------------------*/
/*--------------------- PROTECTED PART OF THE CLASS ------------------------*/
/*--------------------------------------------------------------------------*/	

 protected:

  //FNSS formats parsers
  fnss::Topology topology;
  fnss::TrafficMatrixSequence traffic_matrix_sequence;
  fnss::TrafficMatrix traffic_matrix;
  set<string> nodes;
  set<pair <string, string> > edges;
  set<pair <string, string> > flows;

  //parsed info about the instance	
  int nnodes;
  int nflows;
  int nlinks;

  DCR::DCRFlow *Flows;
  DCR::DCRLink *Links;	

  char format;
  char *fname;

 };

#endif

/*--------------------------------------------------------------------------*/
/*-------------------------- End File DCRwriter.h ---------------------------*/
/*--------------------------------------------------------------------------*/
